@@ -13,6 +13,12 @@ describe('MagicString', () => {
 
 			assert.equal(s.filename, 'foo.js');
 		});
+
+		it('stores ignore-list hint', () => {
+			const s = new MagicString('abc', { ignoreList: true });
+
+			assert.equal(s.ignoreList, true);
+		});
 	});
 
 	describe('append', () => {
@@ -418,6 +424,73 @@ describe('MagicString', () => {
 			const map = s.generateMap();
 			assert.equal(map.mappings, 'IAAA');
 		});
+
+		it('generates x_google_ignoreList', () => {
+			const s = new MagicString('function foo(){}', {
+				ignoreList: true
+		  });
+
+			const map = s.generateMap({ source: 'foo.js' });
+			assert.deepEqual(map.sources, ['foo.js']);
+			assert.deepEqual(map.x_google_ignoreList, [0]);
+		});
+
+		it('generates segments per word boundary with hires "boundary"', () => {
+			const s = new MagicString('function foo(){ console.log("bar") }');
+
+			// rename bar to hello
+			s.overwrite(29, 32, 'hello');
+
+			const map = s.generateMap({
+				file: 'output.js',
+				source: 'input.js',
+				includeContent: true,
+				hires: 'boundary'
+			});
+
+			assert.equal(map.mappings, 'AAAA,QAAQ,CAAC,GAAG,CAAC,CAAC,CAAC,CAAC,OAAO,CAAC,GAAG,CAAC,CAAC,KAAG,CAAC,CAAC,CAAC');
+
+			const smc = new SourceMapConsumer(map);
+			let loc;
+
+			loc = smc.originalPositionFor({ line: 1, column: 3 });
+			assert.equal(loc.line, 1);
+			assert.equal(loc.column, 0);
+
+			loc = smc.originalPositionFor({ line: 1, column: 11 });
+			assert.equal(loc.line, 1);
+			assert.equal(loc.column, 9);
+
+			loc = smc.originalPositionFor({ line: 1, column: 29 });
+			assert.equal(loc.line, 1);
+			assert.equal(loc.column, 29);
+
+			loc = smc.originalPositionFor({ line: 1, column: 35 });
+			assert.equal(loc.line, 1);
+			assert.equal(loc.column, 33);
+		});
+
+		it('generates a correct source map with update using a content containing a new line', () => {
+			const s = new MagicString('foobar');
+			s.update(3, 4, '\nbb');
+			assert.equal(s.toString(), 'foo\nbbar');
+
+			const map = s.generateMap({ hires: true });
+
+			const smc = new SourceMapConsumer(map);
+			const loc = smc.originalPositionFor({ line: 1, column: 3 });
+			assert.equal(loc.line, 1);
+			assert.equal(loc.column, 3);
+			const loc2 = smc.originalPositionFor({ line: 2, column: 0 });
+			assert.equal(loc2.line, 1);
+			assert.equal(loc2.column, 3);
+			const loc3 = smc.originalPositionFor({ line: 2, column: 1 });
+			assert.equal(loc3.line, 1);
+			assert.equal(loc3.column, 3);
+			const loc4 = smc.originalPositionFor({ line: 2, column: 2 });
+			assert.equal(loc4.line, 1);
+			assert.equal(loc4.column, 4);
+		});
 	});
 
 	describe('getIndentString', () => {
@@ -1287,6 +1360,27 @@ describe('MagicString', () => {
 			assert.equal(s.toString(), 'defghi');
 		});
 
+		it('should trim replaced content with end space', () => {
+			const s = new MagicString('  test  ');
+			s.overwrite(2, 6, 'abcd  ');
+			s.trimEnd();
+			assert.equal(s.toString(), '  abcd');
+		});
+
+		it('should trim replaced content with start space', () => {
+			const s = new MagicString('  test  ');
+			s.overwrite(0, 6, '  abcd');
+			s.trimStart();
+			assert.equal(s.toString(), 'abcd  ');
+		});
+
+		it('should trim replaced content with start space', () => {
+			const s = new MagicString('  test  ');
+			s.overwrite(0, 8, '  abcd  ');
+			s.trim();
+			assert.equal(s.toString(), 'abcd');
+		});
+
 		it('should trim original content before replaced content', () => {
 			const s = new MagicString('abc   def');
 
@@ -1418,7 +1512,7 @@ describe('MagicString', () => {
 			const s = new MagicString(' abcde   fghijkl ');
 
 			assert.ok(!s.hasChanged());
-		
+
 			assert.ok(s.clone().prepend('  ').hasChanged());
 			assert.ok(s.clone().overwrite(1, 2, 'b').hasChanged());
 			assert.ok(s.clone().remove(1, 6).hasChanged());
@@ -1432,7 +1526,7 @@ describe('MagicString', () => {
 			assert.ok(clone.hasChanged());
 		});
 	});
-  
+
 	describe('replace', () => {
 		it('works with string replace', () => {
 			const code = '1 2 1 2';
@@ -1503,7 +1597,7 @@ describe('MagicString', () => {
 			);
 		});
 	});
-  
+
 	describe('replaceAll', () => {
 		it('works with string replace', () => {
 			assert.strictEqual(
